changeset 737:3fb7acf2856f draft

Another sync.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 08 Jul 2015 12:00:23 +0200
parents 7104c1538b7d
children 4010d1af2727
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 76 insertions(+), 71 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Jul 07 12:35:57 2015 +0200
+++ b/ChangeLog	Wed Jul 08 12:00:23 2015 +0200
@@ -1,3 +1,8 @@
+2015-07-07  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Another sync.
+
 2015-07-07  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Jul 07 12:35:57 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jul 08 12:00:23 2015 +0200
@@ -12181,7 +12181,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -12190,13 +12190,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -12205,13 +12205,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -12220,13 +12220,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -12235,13 +12235,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -12250,13 +12250,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12265,13 +12265,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -12280,13 +12280,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -12295,13 +12295,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -12310,13 +12310,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -12325,13 +12325,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -12181,7 +12181,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.blue.
      *